pub struct BodyStream {
pub len: Option<u64>,
pub is_seekable: bool,
pub clonable: bool,
/* private fields */
}Expand description
A BodyStream is an async reader that can be used to read the body of a response.
Fields
len: Option<u64>Content length (if known)
is_seekable: boolTrue when the stream is seekable (most often not, unless it’s backed by a memory buffer)
clonable: boolCan be cloned to create a new independent stream starting at the beginning
Implementations
Sourceimpl BodyStream
impl BodyStream
Sourcepub fn new(inner: BoxedAsyncRead, len: Option<u64>) -> Self
pub fn new(inner: BoxedAsyncRead, len: Option<u64>) -> Self
Creates a non-seekable, non-clonable stream from the given reader and optional length
Sourcepub fn from_bytes(bytes: Bytes) -> Self
pub fn from_bytes(bytes: Bytes) -> Self
Converts a series of bytes into a body stream