FetchKeyData

Struct FetchKeyData 

pub struct FetchKeyData {
    pub url: Url,
    pub method: Method,
    pub headers: HeaderMap,
}
A fetch key data is a key that is used to find out if two requests want to fetch the same resource. If this is true, the requests are bundled so only once the resource will be fetched.

Fields

url: Url

URL fetched

method: Method

HTTP method used (GET, POST etc.)

headers: HeaderMap

HTTP headers

Implementations

Source

impl FetchKeyData

pub fn new(url: Url) -> Self

Creates a new fetch key data with the given URL, method GET and no headers

pub fn generate(&self) -> Option<String>

Generates a key for coalescing in-flight requests based on the request’s method, URL, and headers.