pub struct FetchKeyData {
pub url: Url,
pub method: Method,
pub headers: HeaderMap,
}Expand description
A fetch key data is a key that is used to find out if two requests want to fetch the same resource. If this is true, the requests are bundled so only once the resource will be fetched.
Fields
url: UrlURL fetched
method: MethodHTTP method used (GET, POST etc.)
headers: HeaderMapHTTP headers
Implementations